
function DrawHUD()

	-- Work out which one to draw next
	if SETTINGS.HUDTYPE == _LANG.HUDs.SIMPLEABOVE[SETTINGS.LANGUAGE] then
		DrawSimpleHUD("ABOVE");
	elseif SETTINGS.HUDTYPE == _LANG.HUDs.SIMPLEBELOW[SETTINGS.LANGUAGE] then
		DrawSimpleHUD("BELOW");
	end

	SETTINGS.HUDVISIBLE = true;
	RegisterEvents();

end


-- This function clears the HUD display so a new one can be drawn
function ClearHUD()

	if wHUDParent ~= nil then DestroyControl(wHUDParent) end;
	SETTINGS.HUDVISIBLE = false;

end


-- This function recolours the HUD
function RefreshHUD()

	if wHUDParent ~= nil then

		local NUMBARS = 1;


		if MYCHAR:IsInCombat() == false and SETTINGS.COMBATFADE == true then
			wHUDParent:SetOpacity(SETTINGS.OCOPACITY);
		else
			wHUDParent:SetOpacity(SETTINGS.MORALE.OPACITY);
		end

		wMoraleBar:SetBackColor(GetTurbineColor(SETTINGS.MORALE.COLOR));
		wMoraleBar:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
		wMoraleBarBack:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
		lblMorale:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);

		if GetMountType(MYMOUNT) == "WARSTEED" then
			NUMBARS = 3;

			wPowerBar:SetBackColor(GetTurbineColor(SETTINGS.POWER.COLOR));
			wPowerBar:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
			wPowerBarBack:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
			wPowerBarBack:SetPosition(0,1*(SETTINGS.BARHEIGHT+SETTINGS.BARSPACE));
			lblPower:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);

			wFuryBar:SetBackColor(GetTurbineColor(SETTINGS.FURY.COLOR));
			wFuryBar:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
			wFuryBarBack:SetPosition(0,2*(SETTINGS.BARHEIGHT+SETTINGS.BARSPACE));
			wFuryBarBack:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
			lblFury:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
		end

		if SETTINGS.BARHEIGHT < 8 then
			if lblMorale ~= nil then lblMorale:SetVisible(false) end;
			if lblPower ~= nil then lblPower:SetVisible(false) end;
			if lblFury ~= nil then lblFury:SetVisible(false) end;
		else
			if lblMorale ~= nil then lblMorale:SetVisible(true) end;
			if lblPower ~= nil then lblPower:SetVisible(true) end;
			if lblFury ~= nil then lblFury:SetVisible(true) end;
		end

		wHUDParent:SetSize(SETTINGS.BARWIDTH,(NUMBARS*SETTINGS.BARHEIGHT)+((NUMBARS-1)*SETTINGS.BARSPACE));
		wHUDParent:SetPosition((SCREENWIDTH/2)-(SETTINGS.BARWIDTH/2),SETTINGS.SIMPLETOP);

		RegisterEvents();

	end

end


-- Simple style HUD
function DrawSimpleHUD(POSITION)

	local NUMBARS = 1;
	local PARENTBACK = Turbine.UI.Color(0.5,0,0,0);

	wHUDParent = Turbine.UI.Window();
	wHUDParent:SetMouseVisible(false);
	wHUDParent:SetVisible(SETTINGS.SHOWSCREEN);

	if MYCHAR:IsInCombat() == false and SETTINGS.COMBATFADE == true then
		wHUDParent:SetOpacity(SETTINGS.OCOPACITY);
	else
		wHUDParent:SetOpacity(SETTINGS.MORALE.OPACITY);
	end


	-- morale bar (universal)
	wMoraleBarBack = Turbine.UI.Control();
	wMoraleBarBack:SetParent(wHUDParent);
	wMoraleBarBack:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
	wMoraleBarBack:SetPosition(0,0);
	wMoraleBarBack:SetBackColor(PARENTBACK);
	wMoraleBarBack:SetMouseVisible(false);

	wMoraleBar = Turbine.UI.Control();
	wMoraleBar:SetParent(wMoraleBarBack);
	wMoraleBar:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
	wMoraleBar:SetBackColorBlendMode(2);
	wMoraleBar:SetBackColor(GetTurbineColor(SETTINGS.MORALE.COLOR));
	wMoraleBar:SetVisible(true);
	wMoraleBar:SetMouseVisible(false);

	lblMorale = Turbine.UI.Label();
	lblMorale:SetParent(wMoraleBarBack);
	lblMorale:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
	lblMorale:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	lblMorale:SetFont(Verdana10);
	lblMorale:SetOutlineColor(Turbine.UI.Color.Black);
	lblMorale:SetFontStyle(Turbine.UI.FontStyle.Outline);
	lblMorale:SetMouseVisible(false);


	-- Add bars for power and fury if warsteed
	if GetMountType(MYMOUNT) == "WARSTEED" then

		NUMBARS = 3;

		-- POWER BAR --
		wPowerBarBack = Turbine.UI.Control();
		wPowerBarBack:SetParent(wHUDParent);
		wPowerBarBack:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
		wPowerBarBack:SetPosition(0,1*(SETTINGS.BARHEIGHT+SETTINGS.BARSPACE));
		wPowerBarBack:SetBackColor(PARENTBACK);
		wPowerBarBack:SetMouseVisible(false);

		wPowerBar = Turbine.UI.Control();
		wPowerBar:SetParent(wPowerBarBack);
		wPowerBar:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
		wPowerBar:SetBackColorBlendMode(2);
		wPowerBar:SetBackColor(GetTurbineColor(SETTINGS.POWER.COLOR));
		wPowerBar:SetMouseVisible(false);

		lblPower = Turbine.UI.Label();
		lblPower:SetParent(wPowerBarBack);
		lblPower:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
		lblPower:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
		lblPower:SetFont(Verdana10);
		lblPower:SetOutlineColor(Turbine.UI.Color.Black);
		lblPower:SetFontStyle(Turbine.UI.FontStyle.Outline);
		lblPower:SetMouseVisible(false);


		-- FURY BAR --
		wFuryBarBack = Turbine.UI.Control();
		wFuryBarBack:SetParent(wHUDParent);
		wFuryBarBack:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
		wFuryBarBack:SetPosition(0,2*(SETTINGS.BARHEIGHT+SETTINGS.BARSPACE));
		wFuryBarBack:SetBackColor(PARENTBACK);
		wFuryBarBack:SetMouseVisible(false);

		wFuryBar = Turbine.UI.Control();
		wFuryBar:SetParent(wFuryBarBack);
		wFuryBar:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
		wFuryBar:SetBackColorBlendMode(2);
		wFuryBar:SetBackColor(GetTurbineColor(SETTINGS.FURY.COLOR));
		wFuryBar:SetMouseVisible(false);

		lblFury = Turbine.UI.Label();
		lblFury:SetParent(wFuryBarBack);
		lblFury:SetSize(SETTINGS.BARWIDTH,SETTINGS.BARHEIGHT);
		lblFury:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
		lblFury:SetFont(Verdana10);
		lblFury:SetOutlineColor(Turbine.UI.Color.Black);
		lblFury:SetFontStyle(Turbine.UI.FontStyle.Outline);
		lblFury:SetMouseVisible(false);

	end

	if SETTINGS.BARHEIGHT < 8 then
		if lblMorale ~= nil then lblMorale:SetVisible(false) end;
		if lblPower ~= nil then lblPower:SetVisible(false) end;
		if lblFury ~= nil then lblFury:SetVisible(false) end;
	else
		if lblMorale ~= nil then lblMorale:SetVisible(true) end;
		if lblPower ~= nil then lblPower:SetVisible(true) end;
		if lblFury ~= nil then lblFury:SetVisible(true) end;
	end

	if POSITION == "ABOVE" then
		SETTINGS.SIMPLETOP = SETTINGS.SIMPLEABOVE.TOP - SETTINGS.SIMPLEABOVE.OFFSET;
	else
		SETTINGS.SIMPLETOP = SETTINGS.SIMPLEBELOW.TOP + SETTINGS.SIMPLEBELOW.OFFSET;
	end

	wHUDParent:SetSize(SETTINGS.BARWIDTH,(NUMBARS*SETTINGS.BARHEIGHT)+((NUMBARS-1)*SETTINGS.BARSPACE));
	wHUDParent:SetPosition((SCREENWIDTH/2)-(SETTINGS.BARWIDTH/2),SETTINGS.SIMPLETOP);

end


-- MORALE functions
function SetMoraleBar(CURMORALE,MAXMORALE)
	wMoraleBar:SetWidth((CURMORALE/MAXMORALE)*SETTINGS.BARWIDTH);

	if SETTINGS.VALUEFORMAT == _LANG.VALUEFORMAT[1][SETTINGS.LANGUAGE] then -- Cur/Max
		lblMorale:SetText(CommaNumber(CURMORALE) .. "/" .. CommaNumber(MAXMORALE));
	elseif SETTINGS.VALUEFORMAT == _LANG.VALUEFORMAT[2][SETTINGS.LANGUAGE] then -- Percentage
		lblMorale:SetText(tostring(RoundNumber(100*(CURMORALE/MAXMORALE))) .. "%");
	elseif SETTINGS.VALUEFORMAT == _LANG.VALUEFORMAT[3][SETTINGS.LANGUAGE] then -- Cur/Max (%)
		lblMorale:SetText(CommaNumber(CURMORALE) .. "/" .. CommaNumber(MAXMORALE) .. "  (" .. tostring(RoundNumber(100*(CURMORALE/MAXMORALE))) .. "%)");
	else -- None
		lblMorale:SetText("");
	end
end


-- POWER functions
function SetPowerBar(CURPOWER,MAXPOWER)
	wPowerBar:SetWidth((CURPOWER/MAXPOWER)*SETTINGS.BARWIDTH);

	if SETTINGS.VALUEFORMAT == _LANG.VALUEFORMAT[1][SETTINGS.LANGUAGE] then -- Cur/Max
		lblPower:SetText(CommaNumber(CURPOWER) .. "/" .. CommaNumber(MAXPOWER));
	elseif SETTINGS.VALUEFORMAT == _LANG.VALUEFORMAT[2][SETTINGS.LANGUAGE] then -- Percentage
		lblPower:SetText(tostring(RoundNumber(100*(CURPOWER/MAXPOWER))) .. "%");
	elseif SETTINGS.VALUEFORMAT == _LANG.VALUEFORMAT[3][SETTINGS.LANGUAGE] then -- Cur/Max (%)
		lblPower:SetText(CommaNumber(CURPOWER) .. "/" .. CommaNumber(MAXPOWER) .. "  (" .. tostring(RoundNumber(100*(CURPOWER/MAXPOWER))) .. "%)");
	else -- None
		lblPower:SetText("");
	end

end


-- FURY functions
function SetFuryBar(CURFURY,MAXFURY)
	wFuryBar:SetWidth((CURFURY/MAXFURY)*SETTINGS.BARWIDTH);

	if SETTINGS.VALUEFORMAT == _LANG.VALUEFORMAT[1][SETTINGS.LANGUAGE] then -- Cur/Max
		lblFury:SetText(CommaNumber(CURFURY) .. "/" .. CommaNumber(MAXFURY));
	elseif SETTINGS.VALUEFORMAT == _LANG.VALUEFORMAT[2][SETTINGS.LANGUAGE] then -- Percentage
		lblFury:SetText(tostring(RoundNumber(100*(CURFURY/MAXFURY))) .. "%");
	elseif SETTINGS.VALUEFORMAT == _LANG.VALUEFORMAT[3][SETTINGS.LANGUAGE] then -- Cur/Max (%)
		lblFury:SetText(CommaNumber(CURFURY) .. "/" .. CommaNumber(MAXFURY) .. "  (" .. tostring(RoundNumber(100*(CURFURY/MAXFURY))) .. "%)");
	else -- None
		lblFury:SetText("");
	end

end


function RegisterEvents()

	if MYMOUNT ~= nil then

		-- MORALE Event listeners
		MYMOUNT.MoraleChanged = function (sender,args)
			SetMoraleBar(RoundNumber(MYMOUNT:GetMorale()),MYMOUNT:GetMaxMorale());
		end

		MYMOUNT.MaxMoraleChanged = function ()
			SetMoraleBar(RoundNumber(MYMOUNT:GetMorale()),MYMOUNT:GetMaxMorale());
		end

		-- Set starting values
		SetMoraleBar(RoundNumber(MYMOUNT:GetMorale()),MYMOUNT:GetMaxMorale());


		if GetMountType(MYMOUNT) == "WARSTEED" then

			-- Event listeners
			MYMOUNT.PowerChanged = function (sender,args)
				SetPowerBar(RoundNumber(MYMOUNT:GetPower()),MYMOUNT:GetMaxPower());
			end

			MYMOUNT.MaxPowerChanged = function ()
				SetPowerBar(RoundNumber(MYMOUNT:GetPower()),MYMOUNT:GetMaxPower());
			end


			MYMOUNT.FuryChanged = function (sender,args)
				SetFuryBar(RoundNumber(MYMOUNT:GetFury()),MYMOUNT:GetMaxFury());
			end

			MYMOUNT.MaxFuryChanged = function ()
				SetFuryBar(RoundNumber(MYMOUNT:GetFury()),MYMOUNT:GetMaxFury());
			end

			-- Set starting values
			SetPowerBar(RoundNumber(MYMOUNT:GetPower()),MYMOUNT:GetMaxPower());
			SetFuryBar(RoundNumber(MYMOUNT:GetFury()),MYMOUNT:GetMaxFury());

		end

	end

end




